@@ -1,8 +1,8 @@
 /* Copyright 2003-2004 Roger Dingledine
    Copyright 2004-2005 Roger Dingledine, Nick Mathewson */
 /* See LICENSE for licensing information */
-/* $Id: container.c,v 1.25 2005/04/03 06:00:00 nickm Exp $ */
-const char container_c_id[] = "$Id: container.c,v 1.25 2005/04/03 06:00:00 nickm Exp $";
+/* $Id: container.c,v 1.25.2.1 2005/07/19 21:33:12 arma Exp $ */
+const char container_c_id[] = "$Id: container.c,v 1.25.2.1 2005/07/19 21:33:12 arma Exp $";
 
 #include "compat.h"
 #include "util.h"
@@ -354,20 +354,28 @@ char *smartlist_join_strings2(smartlist_t *sl, const char *join,
 
   tor_assert(sl);
   tor_assert(join);
+
+  if (terminate)
+    n = join_len;
+
   for (i = 0; i < sl->num_used; ++i) {
     n += strlen(sl->list[i]);
-    n += join_len;
+    if (i+1 < sl->num_used) /* avoid double-counting the last one */
+      n += join_len;
   }
-  if (!terminate) n -= join_len;
   dst = r = tor_malloc(n+1);
   for (i = 0; i < sl->num_used; ) {
     for (src = sl->list[i]; *src; )
       *dst++ = *src++;
-    if (++i < sl->num_used || terminate) {
+    if (++i < sl->num_used) {
       memcpy(dst, join, join_len);
       dst += join_len;
     }
   }
+  if (terminate) {
+    memcpy(dst, join, join_len);
+    dst += join_len;
+  }
   *dst = '\0';
 
   if (len_out)
