@@ -2,8 +2,8 @@
  * Copyright 2001-2004 Roger Dingledine.
  * Copyright 2004-2005 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: connection_edge.c,v 1.327.2.1 2005/06/07 18:03:33 nickm Exp $ */
-const char connection_edge_c_id[] = "$Id: connection_edge.c,v 1.327.2.1 2005/06/07 18:03:33 nickm Exp $";
+/* $Id: connection_edge.c,v 1.327.2.2 2005/07/01 01:56:07 arma Exp $ */
+const char connection_edge_c_id[] = "$Id: connection_edge.c,v 1.327.2.2 2005/07/01 01:56:07 arma Exp $";
 
 /**
  * \file connection_edge.c
@@ -1504,7 +1504,7 @@ connection_exit_connect(connection_t *conn) {
   uint16_t port;
 
   if (!connection_edge_is_rendezvous_stream(conn) &&
-      router_compare_to_my_exit_policy(conn) == ADDR_POLICY_REJECTED) {
+      router_compare_to_my_exit_policy(conn)) {
     log_fn(LOG_INFO,"%s:%d failed exit policy. Closing.",
            safe_str(conn->address), conn->port);
     connection_edge_end(conn, END_STREAM_REASON_EXITPOLICY, conn->cpath_layer);
